==> eugene-maven-plugin-2.6-sources.jar: org/nuiton/eugene/plugin/SmartGenerateMojo.java <==
/*
 * #%L
 * EUGene :: Maven plugin
 * 
 * $Id: SmartGenerateMojo.java 1174 2012-08-17 08:44:36Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/eugene/tags/eugene-2.6/eugene-maven-plugin/src/main/java/org/nuiton/eugene/plugin/SmartGenerateMojo.java $
 * %%
 * Copyright (C) 2006 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.eugene.plugin;

import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.ResolutionScope;

/**
 * Smart file generator.
 * <p/>
 * Fill inputs and mojo will chained needed writer.
 * <p/>
 *
 * @author tchemit <chemit@codelutin.com>
 * @deprecated since 2.5, prefer use now the {@code generate} goal.
 */
@Mojo(name = "smart-generate",
      requiresProject = true,
      requiresDirectInvocation = true,
      requiresDependencyResolution = ResolutionScope.COMPILE)
@Deprecated
public class SmartGenerateMojo extends GenerateMojo {

    @Override
    protected void init() throws Exception {

        getLog().warn("================================================================================");
        getLog().warn("");
        getLog().warn("Since version 2.5, smart-generate is deprecated (it will be removed in version 3.0).");
        getLog().warn("Prefer use now the generate goal.");
        getLog().warn("");
        getLog().warn("See http://maven-site.nuiton.org/eugene/eugene-maven-plugin/generate-mojo.html");
        getLog().warn("See http://nuiton.org/issues/2251");
        getLog().warn("");
        getLog().warn("================================================================================");

        super.init();
    }

}

==> eugene-maven-plugin-2.6.1-sources.jar: org/nuiton/eugene/plugin/SmartGenerateMojo.java <==
/*
 * #%L
 * EUGene :: Maven plugin
 * 
 * $Id: SmartGenerateMojo.java 1229 2013-01-11 10:56:23Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/eugene/tags/eugene-2.6.1/eugene-maven-plugin/src/main/java/org/nuiton/eugene/plugin/SmartGenerateMojo.java $
 * %%
 * Copyright (C) 2006 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.eugene.plugin;

import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.ResolutionScope;

/**
 * Smart file generator.
 * <p/>
 * Fill inputs and mojo will chained needed writer.
 * <p/>
 *
 * @author tchemit <chemit@codelutin.com>
 * @deprecated since 2.5, prefer use now the {@code generate} goal.
 */
@Mojo(name = "smart-generate",
      requiresProject = true,
      requiresDirectInvocation = false,
      requiresDependencyResolution = ResolutionScope.COMPILE)
@Deprecated
public class SmartGenerateMojo extends GenerateMojo {

    @Override
    protected void init() throws Exception {

        getLog().warn("================================================================================");
        getLog().warn("");
        getLog().warn("Since version 2.5, smart-generate is deprecated (it will be removed in version 3.0).");
        getLog().warn("Prefer use now the generate goal.");
        getLog().warn("");
        getLog().warn("See http://maven-site.nuiton.org/eugene/eugene-maven-plugin/generate-mojo.html");
        getLog().warn("See http://nuiton.org/issues/2251");
        getLog().warn("");
        getLog().warn("================================================================================");

        super.init();
    }

}
